@@ -101,8 +101,6 @@ class Desktop:
             self.printERROR(self.clTempl.getError().strip())
             return False
         else:
-            if self.verbose:
-                self.displayTemplatesApplied(dirsFiles)
             return dirsFiles
 
     def initVars(self,datavars=None):
